@@ -27,16 +27,15 @@
 #define __SEAHORSE_VALIDITY_H__
 
 #include <gtk/gtk.h>
-#include "cryptui.h"
 
 typedef enum {
-    SEAHORSE_VALIDITY_REVOKED =     CRYPTUI_VALIDITY_REVOKED,
-    SEAHORSE_VALIDITY_DISABLED =    CRYPTUI_VALIDITY_DISABLED,
-    SEAHORSE_VALIDITY_UNKNOWN =     CRYPTUI_VALIDITY_UNKNOWN,
-    SEAHORSE_VALIDITY_NEVER =       CRYPTUI_VALIDITY_NEVER,
-    SEAHORSE_VALIDITY_MARGINAL =    CRYPTUI_VALIDITY_MARGINAL,
-    SEAHORSE_VALIDITY_FULL =        CRYPTUI_VALIDITY_FULL,
-    SEAHORSE_VALIDITY_ULTIMATE =    CRYPTUI_VALIDITY_ULTIMATE
+    SEAHORSE_VALIDITY_REVOKED =     -3,
+    SEAHORSE_VALIDITY_DISABLED =    -2,
+    SEAHORSE_VALIDITY_NEVER =       -1,
+    SEAHORSE_VALIDITY_UNKNOWN =      0,
+    SEAHORSE_VALIDITY_MARGINAL =     1,
+    SEAHORSE_VALIDITY_FULL =         5,
+    SEAHORSE_VALIDITY_ULTIMATE =    10
 } SeahorseValidity;
 
 const gchar*        seahorse_validity_get_string    (SeahorseValidity validity);
