@@ -43,7 +43,7 @@
 #define  GPG_VERSION_PREFIX1   "1."
 #define  GPG_VERSION_PREFIX2   "2."
 
-static gchar gpg_homedir[MAXPATHLEN];
+static gchar *gpg_homedir;
 static gboolean gpg_options_inited = FALSE;
 
 static gboolean
@@ -77,6 +77,9 @@ find_config_file (gboolean read, GError **err)
     g_assert (gpg_options_inited);
     g_assert (!err || !*err);
 
+    if (!gpg_homedir)
+        return NULL;
+
     /* Check for and open ~/.gnupg/gpg.conf */
     conf = g_strconcat (gpg_homedir, "/gpg.conf", NULL);
     if (g_file_test (conf, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_EXISTS)) 
@@ -208,16 +211,14 @@ parse_home_directory (gpgme_engine_info_t engine, GError **err)
                     *x = 0;
                     g_strstrip (t);
 
-                    gpg_homedir[0] = 0;
+                    g_free (gpg_homedir);
 
                     /* If it's not a rooted path then expand */
                     if (t[0] == '~') {
-                        g_strlcpy (gpg_homedir, g_get_home_dir (),
-                                   sizeof (gpg_homedir));
-                        t++;
+                        gpg_homedir = g_strconcat (g_get_home_dir(), ++t, NULL);
+                    } else {
+                        gpg_homedir = g_strdup (t);
                     }
-
-                    g_strlcat (gpg_homedir, t, sizeof (gpg_homedir));
                     found = TRUE;
                 }
             }
@@ -245,7 +246,7 @@ gpg_options_init (GError **err)
 
         gerr = gpgme_get_engine_info (&engine);
         g_return_val_if_fail (GPG_IS_OK (gerr),
-                              (seahorse_gpgme_to_error (gerr, err), FALSE));
+                              (seahorse_gpgme_propagate_error (gerr, err), FALSE));
 
         /* Look for the OpenPGP engine */
         while (engine && engine->protocol != GPGME_PROTOCOL_OpenPGP)
@@ -258,7 +259,7 @@ gpg_options_init (GError **err)
         g_return_val_if_fail (engine && engine->version && engine->file_name &&
                               (g_str_has_prefix (engine->version, GPG_VERSION_PREFIX1) ||
                                g_str_has_prefix (engine->version, GPG_VERSION_PREFIX2)),
-                              (seahorse_gpgme_to_error (GPG_E (GPG_ERR_INV_ENGINE), err), FALSE));
+                              (seahorse_gpgme_propagate_error (GPG_E (GPG_ERR_INV_ENGINE), err), FALSE));
 
         /* Now run the binary and read in the home directory */
         if (!parse_home_directory (engine, err))
@@ -391,14 +392,12 @@ process_conf_edits (GArray *lines, const gchar *options[], gchar *values[])
     gchar *t;
     gchar *n;
     gchar *line;
-    gsize length;
     guint i, j;
 
     for (j = 0; j < lines->len; j++) {
         line = g_array_index (lines, gchar*, j);
         g_assert (line != NULL);        
-        length = strlen(line);
-        
+
         /* 
          * Does this line have an ending? 
          * We use this below when appending lines.
