@@ -2,7 +2,8 @@
  * Seahorse
  * 
  * Copyright (C) 2008 Stefan Walter
- * 
+ * Copyright (C) 2011 Collabora Ltd.
+ *
  * This program is free software; you can redistribute it and/or modify 
  * it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
@@ -25,7 +26,6 @@
 #include "seahorse-key-manager-store.h"
 #include "seahorse-windows.h"
 
-#include "seahorse-operation.h"
 #include "seahorse-progress.h"
 
 #include <glib/gi18n.h>
@@ -45,6 +45,7 @@ struct _SeahorseKeyserverResultsPrivate {
 	SeahorseKeyManagerStore *store;
 	SeahorseSet *objects;
 	SeahorseObjectPredicate pred;
+	GSettings *settings;
 };
 
 G_DEFINE_TYPE (SeahorseKeyserverResults, seahorse_keyserver_results, SEAHORSE_TYPE_VIEWER);
@@ -106,11 +107,19 @@ fire_selection_changed (SeahorseKeyserverResults* self)
 	selection = gtk_tree_view_get_selection (self->pv->view);
 	rows = gtk_tree_selection_count_selected_rows (selection);
 	seahorse_viewer_set_numbered_status (SEAHORSE_VIEWER (self), ngettext ("Selected %d key", "Selected %d keys", rows), rows);
-	gtk_action_group_set_sensitive (self->pv->object_actions, rows > 0);
+	if (self->pv->object_actions)
+		gtk_action_group_set_sensitive (self->pv->object_actions, rows > 0);
 	g_signal_emit_by_name (G_OBJECT (SEAHORSE_VIEW (self)), "selection-changed");
 	return FALSE;
 }
 
+/**
+* selection:
+* self: the results object
+*
+* Adds fire_selection_changed as idle function
+*
+**/
 static void 
 on_view_selection_changed (GtkTreeSelection *selection, SeahorseKeyserverResults *self) 
 {
@@ -159,6 +168,13 @@ on_key_list_popup_menu (GtkTreeView* view, SeahorseKeyserverResults* self)
 	return TRUE;
 }
 
+/**
+* action:
+* self: The result object to expand the nodes in
+*
+* Expands all the nodes in the view of the object
+*
+**/
 static void 
 on_view_expand_all (GtkAction* action, SeahorseKeyserverResults* self) 
 {
@@ -168,14 +184,29 @@ on_view_expand_all (GtkAction* action, SeahorseKeyserverResults* self)
 }
 
 
+/**
+* action:
+* self: The result object to collapse the nodes in
+*
+* Collapses all the nodes in the view of the object
+*
+**/
 static void 
 on_view_collapse_all (GtkAction* action, SeahorseKeyserverResults* self) 
+
 {
 	g_return_if_fail (SEAHORSE_IS_KEYSERVER_RESULTS (self));
 	g_return_if_fail (GTK_IS_ACTION (action));
 	gtk_tree_view_collapse_all (self->pv->view);
 }
 
+/**
+* action: the closing action or NULL
+* self: The SeahorseKeyServerResults widget to destroy
+*
+* destroys the widget
+*
+**/
 static void 
 on_app_close (GtkAction* action, SeahorseKeyserverResults* self) 
 {
@@ -193,7 +224,16 @@ on_remote_find (GtkAction* action, SeahorseKeyserverResults* self)
 }
 
 
-/* When this window closes we quit seahorse */
+
+/**
+* widget: sending widget
+* event: ignored
+* self: The SeahorseKeyserverResults widget to destroy
+*
+* When this window closes we quit seahorse
+*
+* Returns TRUE on success
+**/
 static gboolean 
 on_delete_event (GtkWidget* widget, GdkEvent* event, SeahorseKeyserverResults* self) 
 {
@@ -259,6 +299,15 @@ seahorse_keyserver_results_set_selected (SeahorseViewer* base, SeahorseObject* v
 }
 
 
+/**
+* type: The type identifying this object
+* n_props: Number of properties
+* props: Properties
+*
+* Creates a new SeahorseKeyserverResults object, shows the resulting window
+*
+* Returns The SeahorseKeyserverResults object as GObject
+**/
 static GObject* 
 seahorse_keyserver_results_constructor (GType type, guint n_props, GObjectConstructParam *props) 
 {
@@ -318,18 +367,32 @@ seahorse_keyserver_results_constructor (GType type, guint n_props, GObjectConstr
 	
 	/* Our set all nicely filtered */
 	self->pv->objects = seahorse_set_new_full (&self->pv->pred);
-	self->pv->store = seahorse_key_manager_store_new (self->pv->objects, self->pv->view);
+	self->pv->store = seahorse_key_manager_store_new (self->pv->objects, self->pv->view,
+	                                                  self->pv->settings);
 	on_view_selection_changed (selection, self);
 	
 	return G_OBJECT (self);
 }
 
+/**
+* self: The SeahorseKeyserverResults object to init
+*
+* Inits the results object
+*
+**/
 static void
 seahorse_keyserver_results_init (SeahorseKeyserverResults *self)
 {
 	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, SEAHORSE_TYPE_KEYSERVER_RESULTS, SeahorseKeyserverResultsPrivate);
+	self->pv->settings = g_settings_new ("org.gnome.seahorse.manager");
 }
 
+/**
+* obj: SeahorseKeyserverResults object
+*
+* Finalize the results object
+*
+**/
 static void
 seahorse_keyserver_results_finalize (GObject *obj)
 {
@@ -353,10 +416,21 @@ seahorse_keyserver_results_finalize (GObject *obj)
 	if (self->pv->view)
 		gtk_tree_view_set_model (self->pv->view, NULL);
 	self->pv->view = NULL;
-	
+
+	g_clear_object (&self->pv->settings);
+
 	G_OBJECT_CLASS (seahorse_keyserver_results_parent_class)->finalize (obj);
 }
 
+/**
+* obj: The SeahorseKeyserverResults object to set
+* prop_id: Property to set
+* value: Value of this property
+* pspec: GParamSpec for the warning
+*
+* Supported properties are PROP_SEARCH and PROP_SELECTED
+*
+**/
 static void
 seahorse_keyserver_results_set_property (GObject *obj, guint prop_id, const GValue *value, 
                            GParamSpec *pspec)
@@ -383,6 +457,15 @@ seahorse_keyserver_results_set_property (GObject *obj, guint prop_id, const GVal
 	}
 }
 
+/**
+* obj: The SeahorseKeyserverResults object to get properties from
+* prop_id: the ide of the property to get
+* value: Value returned
+* pspec: GParamSpec for the warning
+*
+* Supported properties: PROP_SEARCH and PROP_SELECTED
+*
+**/
 static void
 seahorse_keyserver_results_get_property (GObject *obj, guint prop_id, GValue *value, 
                            GParamSpec *pspec)
@@ -402,6 +485,12 @@ seahorse_keyserver_results_get_property (GObject *obj, guint prop_id, GValue *va
 	}
 }
 
+/**
+* klass: The SeahorseKeyserverResultsClass
+*
+* Inits the class
+*
+**/
 static void
 seahorse_keyserver_results_class_init (SeahorseKeyserverResultsClass *klass)
 {
@@ -427,33 +516,66 @@ seahorse_keyserver_results_class_init (SeahorseKeyserverResultsClass *klass)
 	g_object_class_override_property (G_OBJECT_CLASS (klass), PROP_SELECTED, "selected");
 }
 
-/* -----------------------------------------------------------------------------
- * PUBLIC 
- */
-
-void 
-seahorse_keyserver_results_show (SeahorseOperation* op, GtkWindow* parent, const char* search_text) 
+static void
+on_search_completed (GObject *source,
+                     GAsyncResult *result,
+                     gpointer user_data)
 {
-	SeahorseKeyserverResults* res;
-	GtkWindow *window;
-	
-	g_return_if_fail (SEAHORSE_IS_OPERATION (op));
-	g_return_if_fail (parent == NULL || GTK_IS_WINDOW (parent));
-	g_return_if_fail (search_text != NULL);
-	
-	res = g_object_new (SEAHORSE_TYPE_KEYSERVER_RESULTS, "name", "keyserver-results", "search", search_text, NULL);
-	
-	/* Destorys itself with destroy */
-	g_object_ref_sink (res);
-	
-	if (parent != NULL) {
-		window = GTK_WINDOW (seahorse_widget_get_toplevel (SEAHORSE_WIDGET (res)));
-		gtk_window_set_transient_for (window, parent);
+	SeahorseKeyserverResults *self = SEAHORSE_KEYSERVER_RESULTS (user_data);
+	GError *error = NULL;
+
+	seahorse_context_search_remote_finish (seahorse_context_instance (),
+	                                       result, &error);
+	if (error != NULL) {
+		seahorse_viewer_set_status (SEAHORSE_VIEWER (self), error->message);
+		g_error_free (error);
 	}
 
-	seahorse_progress_status_set_operation (SEAHORSE_WIDGET (res), op);
+	g_object_unref (self);
+}
+/**
+ * seahorse_keyserver_results_show:
+ * @parent: A GTK window as parent (or NULL)
+ * @search_text: The test to search for
+ *
+ * Creates a search results window and adds the operation to it's progress status.
+ *
+ */
+void 
+seahorse_keyserver_results_show (const char* search_text)
+{
+	SeahorseKeyserverResults* self;
+	GCancellable *cancellable;
+
+	g_return_if_fail (search_text != NULL);
+
+	self = g_object_new (SEAHORSE_TYPE_KEYSERVER_RESULTS,
+	                     "name", "keyserver-results",
+	                     "search", search_text,
+	                     NULL);
+
+	/* Destorys itself with destroy */
+	g_object_ref_sink (self);
+
+	cancellable = g_cancellable_new ();
+	seahorse_context_search_remote_async (seahorse_context_instance (),
+	                                      search_text, cancellable,
+	                                      on_search_completed,
+	                                      g_object_ref (self));
+
+	seahorse_progress_attach (cancellable, SEAHORSE_WIDGET (self));
+
+	g_object_unref (cancellable);
 }
 
+/**
+ * seahorse_keyserver_results_get_search:
+ * @self:  SeahorseKeyserverResults object to get the search string from
+ *
+ *
+ *
+ * Returns: The search string in from the results
+ */
 const gchar* 
 seahorse_keyserver_results_get_search (SeahorseKeyserverResults* self) 
 {
