@@ -2,6 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2006 Stefan Walter
+ * Copyright (C) 2011 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,12 +32,12 @@
 #include "seahorse-ssh.h"
 #include "seahorse-ssh-operation.h"
 
-#include "seahorse-widget.h"
-#include "seahorse-util.h"
-#include "seahorse-progress.h"
 #include "seahorse-gtkstock.h"
+#include "seahorse-progress.h"
+#include "seahorse-registry.h"
+#include "seahorse-util.h"
+#include "seahorse-widget.h"
 
-#include "common/seahorse-registry.h"
 
 /* --------------------------------------------------------------------------
  * ACTIONS
@@ -49,7 +50,7 @@ on_ssh_generate_key (GtkAction *action, gpointer unused)
 	
 	g_return_if_fail (GTK_IS_ACTION (action));
 	
-	sksrc = seahorse_context_find_source (seahorse_context_for_app (), SEAHORSE_SSH_TYPE, SEAHORSE_LOCATION_LOCAL);
+	sksrc = seahorse_context_find_source (seahorse_context_instance (), SEAHORSE_SSH_TYPE, SEAHORSE_LOCATION_LOCAL);
 	g_return_if_fail (sksrc != NULL);
 	
 	seahorse_ssh_generate_show (SEAHORSE_SSH_SOURCE (sksrc), NULL);
@@ -81,41 +82,6 @@ seahorse_ssh_generate_register (void)
 #define DSA_SIZE 1024
 #define DEFAULT_RSA_SIZE 2048
 
-static void
-completion_handler (SeahorseOperation *op, gpointer data)
-{
-    GError *error = NULL;
-    if (!seahorse_operation_is_successful (op)) {
-        seahorse_operation_copy_error (op, &error);
-        seahorse_util_handle_error (error, _("Couldn't generate Secure Shell key"));
-        g_clear_error (&error);
-    }
-}
-
-static void
-upload_handler (SeahorseOperation *op, SeahorseWidget *swidget)
-{
-    SeahorseSSHKey *skey;
-    GList *keys;
-    
-    if (!seahorse_operation_is_successful (op) ||
-        seahorse_operation_is_cancelled (op)) {
-		seahorse_widget_destroy (swidget);
-        return;
-	}
-    
-    skey = SEAHORSE_SSH_KEY (seahorse_operation_get_result (op));
-	if (!SEAHORSE_IS_SSH_KEY (skey)) {
-		seahorse_widget_destroy (swidget);
-		return;
-	}
-	
-    keys = g_list_append (NULL, skey);
-    seahorse_ssh_upload_prompt (keys, GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)));
-    g_list_free (keys);
-	seahorse_widget_destroy (swidget);
-}
-
 static void
 on_change (GtkComboBox *combo, SeahorseWidget *swidget)
 {
@@ -124,12 +90,8 @@ on_change (GtkComboBox *combo, SeahorseWidget *swidget)
     
     widget = seahorse_widget_get_widget (swidget, "bits-entry");
     g_return_if_fail (widget != NULL);
-    
-#if GTK_CHECK_VERSION (2,91,2)
+
     t = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combo));
-#else
-    t = gtk_combo_box_get_active_text (combo);
-#endif
     if (t && strstr (t, "DSA")) {
         gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), DSA_SIZE);
         gtk_widget_set_sensitive (widget, FALSE);
@@ -139,11 +101,53 @@ on_change (GtkComboBox *combo, SeahorseWidget *swidget)
     }
 }
 
+static void
+on_generate_complete (GObject *source,
+                      GAsyncResult *result,
+                      gpointer user_data)
+{
+	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
+	GError *error = NULL;
+
+	seahorse_ssh_op_generate_finish (SEAHORSE_SSH_SOURCE (source),
+	                                 result, &error);
+
+	if (error != NULL)
+		seahorse_util_handle_error (&error, swidget, _("Couldn't generate Secure Shell key"));
+
+	g_object_unref (swidget);
+}
+
+static void
+on_generate_complete_and_upload (GObject *source,
+                                 GAsyncResult *result,
+                                 gpointer user_data)
+{
+	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
+	GError *error = NULL;
+	SeahorseObject *object;
+	GList *keys;
+
+	object = seahorse_ssh_op_generate_finish (SEAHORSE_SSH_SOURCE (source),
+	                                          result, &error);
+
+	if (error != NULL) {
+		seahorse_util_handle_error (&error, swidget, _("Couldn't generate Secure Shell key"));
+
+	} else {
+		keys = g_list_append (NULL, object);
+		seahorse_ssh_upload_prompt (keys, GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)));
+		g_list_free (keys);
+	}
+
+	g_object_unref (swidget);
+}
+
 static void
 on_response (GtkDialog *dialog, guint response, SeahorseWidget *swidget)
 {
     SeahorseSSHSource *src;
-    SeahorseOperation *op;
+    GCancellable *cancellable;
     GtkWidget *widget;
     const gchar *email;
     const gchar *t;
@@ -173,11 +177,7 @@ on_response (GtkDialog *dialog, guint response, SeahorseWidget *swidget)
     /* The algorithm */
     widget = seahorse_widget_get_widget (swidget, "algorithm-choice");
     g_return_if_fail (widget != NULL);
-#if GTK_CHECK_VERSION (2,91,2)
     t = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
-#else
-    t = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
-#endif
     if (t && strstr (t, "DSA"))
         type = SSH_ALGO_DSA;
     else
@@ -194,24 +194,14 @@ on_response (GtkDialog *dialog, guint response, SeahorseWidget *swidget)
     
     src = SEAHORSE_SSH_SOURCE (g_object_get_data (G_OBJECT (swidget), "source"));
     g_return_if_fail (SEAHORSE_IS_SSH_SOURCE (src));
-    
+
     /* We start creation */
-    op = seahorse_ssh_operation_generate (src, email, type, bits);
-    g_return_if_fail (op != NULL);
-    
-    /* Watch for errors so we can display */
-    seahorse_operation_watch (op, (SeahorseDoneFunc)completion_handler, NULL, NULL, NULL);
-    
-    /* When completed upload */
-    if (upload) {
-        seahorse_operation_watch (op, (SeahorseDoneFunc)upload_handler, swidget, NULL, NULL);
-		seahorse_widget_set_visible (swidget, swidget->name, FALSE);
-	}
-	else
-		seahorse_widget_destroy (swidget);
-    
-    seahorse_progress_show (op, _("Creating Secure Shell Key"), TRUE);
-    g_object_unref (op);
+    cancellable = g_cancellable_new ();
+    seahorse_ssh_op_generate_async (src, email, type, bits, cancellable,
+                                    upload ? on_generate_complete_and_upload : on_generate_complete,
+                                    g_object_ref (swidget));
+    seahorse_progress_show (cancellable, _("Creating Secure Shell Key"), FALSE);
+    g_object_unref (cancellable);
 }
 
 void
