@@ -2,6 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2005 Stefan Walter
+ * Copyright (C) 2011 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +28,6 @@
 
 #include "seahorse-widget.h"
 #include "seahorse-util.h"
-#include "seahorse-operation.h"
 #include "seahorse-progress.h"
 #include "seahorse-gtkstock.h"
 
@@ -36,29 +36,31 @@
 #include "ssh/seahorse-ssh-operation.h"
 
 static void 
-upload_complete (SeahorseOperation *op, gpointer dummy)
+on_upload_complete (GObject *source,
+                    GAsyncResult *result,
+                    gpointer user_data)
 {
-    GError *err = NULL;
-    
-    if (!seahorse_operation_is_successful (op)) {
-        seahorse_operation_copy_error (op, &err);
-        seahorse_util_handle_error (err, _("Couldn't configure Secure Shell keys on remote computer."));
-        g_clear_error (&err);
-    }    
+	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
+	GError *error = NULL;
+
+	if (!seahorse_ssh_op_upload_finish (SEAHORSE_SSH_SOURCE (source), result, &error))
+		seahorse_util_handle_error (&error, swidget, _("Couldn't configure Secure Shell keys on remote computer."));
+
+	g_object_unref (swidget);
 }
 
-static void
-input_changed (GtkWidget *dummy, SeahorseWidget *swidget)
+G_MODULE_EXPORT void
+on_upload_input_changed (GtkWidget *dummy, SeahorseWidget *swidget)
 {
     GtkWidget *widget;
     const gchar *user, *host, *port;
     gchar *t = NULL;
 
-    widget = glade_xml_get_widget (swidget->xml, "user-label");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "user-label"));
     user = gtk_entry_get_text (GTK_ENTRY (widget));
     g_return_if_fail (user && g_utf8_validate (user, -1, NULL));
 
-    widget = glade_xml_get_widget (swidget->xml, "host-label");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "host-label"));
     host = gtk_entry_get_text (GTK_ENTRY (widget));
     g_return_if_fail (host && g_utf8_validate (host, -1, NULL));
     
@@ -71,7 +73,7 @@ input_changed (GtkWidget *dummy, SeahorseWidget *swidget)
         host = t = g_strndup (host, port - host);
     }
 
-    widget = glade_xml_get_widget (swidget->xml, "ok");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "ok"));
     gtk_widget_set_sensitive (widget, host[0] && !seahorse_util_string_is_whitespace (host) && 
                                       user[0] && !seahorse_util_string_is_whitespace (user));
     
@@ -79,74 +81,24 @@ input_changed (GtkWidget *dummy, SeahorseWidget *swidget)
     g_free (t);
 }
 
-
-static SeahorseOperation*
-upload_via_source (const gchar *user, const gchar *host, const gchar *port, GList *keys)
-{
-    SeahorseMultiOperation *mop = NULL;
-    SeahorseOperation *op = NULL;
-    SeahorseSource *sksrc;
-    SeahorseObject *object;
-    GList *next;
-    
-    seahorse_util_objects_sort (keys);
-    g_assert (keys);
-    
-    while (keys) {
-     
-        /* Break off one set (same keysource) */
-        next = seahorse_util_objects_splice (keys);
-        
-        g_assert (SEAHORSE_IS_OBJECT (keys->data));
-        object = SEAHORSE_OBJECT (keys->data);
-
-        /* Upload via this key source */        
-        sksrc = seahorse_object_get_source (object);
-        g_return_val_if_fail (sksrc != NULL, NULL);
-        
-        g_return_val_if_fail (SEAHORSE_IS_SSH_SOURCE (sksrc), NULL);
-
-        /* If more than one operation start combining */
-        if (op != NULL) {
-            g_assert (mop == NULL);
-            mop = seahorse_multi_operation_new ();
-            seahorse_multi_operation_take (mop, op);
-        }
-
-        /* Start an upload process */
-        op = seahorse_ssh_operation_upload (SEAHORSE_SSH_SOURCE (sksrc), keys, user, host, port);
-        g_return_val_if_fail (op != NULL, NULL);
-
-        /* And combine if necessary */
-        if (mop != NULL) {
-            seahorse_multi_operation_take (mop, op);
-            op = NULL;
-        }
-        
-        g_list_free (keys);
-        keys = next;
-    }
-    
-    return mop ? SEAHORSE_OPERATION (mop) : op;
-}
-
 static void
 upload_keys (SeahorseWidget *swidget)
 {
-    SeahorseOperation *op;
     GtkWidget *widget;
     const gchar *cuser, *chost;
     gchar *user, *host, *port;
     GList *keys;
+    GCancellable *cancellable;
 
     keys = (GList*)g_object_steal_data (G_OBJECT (swidget), "upload-keys");
-    g_return_if_fail (keys != NULL);
+    if (keys == NULL)
+        return;
 
-    widget = glade_xml_get_widget (swidget->xml, "user-label");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "user-label"));
     cuser = gtk_entry_get_text (GTK_ENTRY (widget));
     g_return_if_fail (cuser && g_utf8_validate (cuser, -1, NULL));
     
-    widget = glade_xml_get_widget (swidget->xml, "host-label");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "host-label"));
     chost = (gchar*)gtk_entry_get_text (GTK_ENTRY (widget));
     g_return_if_fail (chost && g_utf8_validate (chost, -1, NULL));
     
@@ -167,19 +119,18 @@ upload_keys (SeahorseWidget *swidget)
 
     seahorse_util_string_trim_whitespace (host);
     seahorse_util_string_trim_whitespace (user);
-    
-    /* This frees |keys| */
-    op = upload_via_source (user, host, port, keys);
+
+    cancellable = g_cancellable_new ();
+
+    /* Start an upload process */
+    seahorse_ssh_op_upload_async (SEAHORSE_SSH_SOURCE (seahorse_object_get_source (keys->data)),
+                                  keys, user, host, port, cancellable, on_upload_complete, NULL);
 
     g_free (host);
     g_free (user);
 
-    g_return_if_fail (op != NULL);
-    seahorse_operation_watch (op, (SeahorseDoneFunc)upload_complete, NULL, NULL, NULL);
-    
-    /* Show the progress window if necessary */
-    seahorse_progress_show (op, _("Configuring Secure Shell Keys..."), FALSE);
-    g_object_unref (op);
+    seahorse_progress_show (cancellable, _("Configuring Secure Shell Keys..."), FALSE);
+    g_object_unref (cancellable);
 }
 
 /**
@@ -200,24 +151,21 @@ seahorse_ssh_upload_prompt (GList *keys, GtkWindow *parent)
     swidget = seahorse_widget_new_allow_multiple ("ssh-upload", parent);
     g_return_if_fail (swidget != NULL);
     
-    win = GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name));
+    win = GTK_WINDOW (GTK_WIDGET (seahorse_widget_get_widget (swidget, swidget->name)));
 
     /* Default to the users current name */
-    w = glade_xml_get_widget (swidget->xml, "user-label");
+    w = GTK_WIDGET (seahorse_widget_get_widget (swidget, "user-label"));
     gtk_entry_set_text (GTK_ENTRY (w), g_get_user_name ());
  
     /* Focus the host */
-    w = glade_xml_get_widget (swidget->xml, "host-label");
+    w = GTK_WIDGET (seahorse_widget_get_widget (swidget, "host-label"));
     gtk_widget_grab_focus (w);    
 
     keys = g_list_copy (keys);
     g_object_set_data_full (G_OBJECT (swidget), "upload-keys", keys, 
                             (GDestroyNotify)g_list_free);
 
-    glade_xml_signal_connect_data (swidget->xml, "input_changed", 
-                                   G_CALLBACK (input_changed), swidget);
-
-    input_changed (NULL, swidget);
+    on_upload_input_changed (NULL, swidget);
 
     for (;;) {
         switch (gtk_dialog_run (GTK_DIALOG (win))) {
